@@ -3,11 +3,12 @@ def data_provider(fn_data_provider):
     Data provider decorator, allows another callable to provide
     the data for the test
     """
-    def test_decorator(fn):
+    def test_decorator(fnct):
+        # pylint: disable=W0613
         def repl(self, *args):
             for i in fn_data_provider():
                 try:
-                    fn(self, *i)
+                    fnct(self, *i)
                 except AssertionError:
                     print "Assertion error caught with data set ", i
                     raise
